View source: R/estimate_functional.R
| logistic_linear | R Documentation |
All specification models can be used as parameter in estimate.functional.
Specification models are used to denote the quantile or expectile level
(depending on the identification function).
The linear logistic specification model depends linear on the state variable with a logistic link function.
logistic_linear(stateVariable, theta, ...)
stateVariable |
state variable |
theta |
parameter |
... |
... |
numeric level
Other specification models:
constant(),
probit_break(),
probit_linear(),
probit_spline2(),
probit_spline3()
# plot linear logistic specification model with constant quantile/expectile level
plot(function(x) logistic_linear(x,theta=c(0,0)), xlim=c(-1,1))
# plot linear logistic specification model with state-dependent quantile/expectile level
plot(function(x) logistic_linear(x,theta=c(0,5)), xlim=c(-1,1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.