| plot.pointfore | R Documentation |
Plots object of class "pointfore"
## S3 method for class 'pointfore'
plot(
x,
conf.levels = c(0.6, 0.9),
pdf = TRUE,
hline = TRUE,
adjust.factor = 1,
limits = NULL,
...
)
x |
object of class "pointfore" |
conf.levels |
one or two confidence levels for pointwise confidence intervals |
pdf |
logic if pdf estimate should be plotted |
hline |
if TRUE plots horizontal line at 0.5. if numeric plot horizontal line at value. |
adjust.factor |
adjust factor for estimating pdf (controls smoothness) |
limits |
2-dimensional vector defining range of x-axis |
... |
other parameters |
plot
#estimate linear probit specification model for quantiles on GDP forecast
res <- estimate.functional(Y=GDP$observation,X=GDP$forecast,
model=probit_linear, stateVariable = GDP$forecast)
#plot results
plot(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.