View source: R/estimate_functional.R
| probit_break | R Documentation |
All specification models can be used as parameter in estimate.functional.
Specification models are used to denote the quantile or expectile level
(depending on the identification function).
The probit break specification model depends has a break at zero and a constant level above and below.
It applies the probit link function.
probit_break(stateVariable, theta, ...)
stateVariable |
state variable |
theta |
parameter |
... |
... |
numeric level
Other specification models:
constant(),
logistic_linear(),
probit_linear(),
probit_spline2(),
probit_spline3()
# plot break probit specification model with constant quantile/expectile level
plot(function(x) probit_break(x,theta=c(0,0)), xlim=c(-1,1))
# plot linear break specification model with state-dependent quantile/expectile level
plot(function(x) probit_break(x,theta=c(0,5)), xlim=c(-1,1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.