View source: R/estimate_functional.R
| probit_linear | R Documentation |
All specification models can be used as parameter in estimate.functional.
Specification models are used to denote the quantile or expectile level
(depending on the identification function).
The linear probit specification model depends linear on the state variable with a probit link function.
probit_linear(stateVariable, theta, ...)
stateVariable |
state variable |
theta |
parameter |
... |
other parameters |
numeric level
Other specification models:
constant(),
logistic_linear(),
probit_break(),
probit_spline2(),
probit_spline3()
# plot linear probit specification model with constant quantile/expectile level
plot(function(x) probit_linear(x,theta=c(0,0)), xlim=c(-1,1))
# plot linear probit specification model with state-dependent quantile/expectile level
plot(function(x) probit_linear(x,theta=c(0,5)), xlim=c(-1,1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.