View source: R/estimate_functional.R
| probit_spline2 | R Documentation |
All specification models can be used as parameter in estimate.functional.
Specification models are used to denote the quantile or expectile level
(depending on the identifciation function).
This specification model depends through a quadratic spline on the state
variable and applies a probit link function.
probit_spline2(stateVariable, theta, ...)
stateVariable |
state variable |
theta |
parameter |
... |
... |
numeric level
Other specification models:
constant(),
logistic_linear(),
probit_break(),
probit_linear(),
probit_spline3()
# plot example of quadratic spline specification model with state-dependent quantile/expectile level
plot(function(x) probit_spline2(x,theta=c(0,1,-1)), xlim=c(-2,2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.